@@ -422,6 +422,7 @@ class Session:
         with contextlib.suppress(AttributeError):
             return self._platform_json
         self._platform_json = PlatformJson(self.npexp_path)
+        update_from_session(self._platform_json, self)
         return self.platform_json
     
     def fix_platform_json(self, path_or_obj: Optional[pathlib.Path | PlatformJson] = None):
@@ -430,7 +431,6 @@ class Session:
         if isinstance(path_or_obj, pathlib.Path):
             path_or_obj = PlatformJson(path_or_obj)
         pj = path_or_obj
-        update_platform_json_fields(pj, self)
         # TODO get files dict, fetch files
     
     @cached_property
